pub struct GetSubscriberCount(pub PortRef<usize>);Expand description
Query the number of active supervision subscribers on this controller.
Tuple Fields
0: PortRef<usize>Trait Implementations
Sourceimpl Bind for GetSubscriberCount
impl Bind for GetSubscriberCount
Sourceimpl Clone for GetSubscriberCount
impl Clone for GetSubscriberCount
Sourcefn clone(&self) -> GetSubscriberCount
fn clone(&self) -> GetSubscriberCount
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetSubscriberCount
impl Debug for GetSubscriberCount
Sourceimpl<'de> Deserialize<'de> for GetSubscriberCount
impl<'de> Deserialize<'de> for GetSubscriberCount
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<A: Referable> Handler<GetSubscriberCount> for ActorMeshController<A>
impl<A: Referable> Handler<GetSubscriberCount> for ActorMeshController<A>
Sourceimpl Named for GetSubscriberCount
impl Named for GetSubscriberCount
Sourcefn typename() -> &'static str
fn typename() -> &'static str
The globally unique type name for the type.
This should typically be the fully qualified Rust name of the type.
Sourcefn typehash() -> u64
fn typehash() -> u64
A globally unique hash for this type.
TODO: actually enforce perfect hashing
Sourcefn typeid() -> TypeId
fn typeid() -> TypeId
The TypeId for this type. TypeIds are unique only within a binary,
and should not be used for global identification.
Sourcefn port() -> u64
fn port() -> u64
The globally unique port for this type. Typed ports are in the range
of 1<<63..1<<64-1.
Sourceimpl PartialEq for GetSubscriberCount
impl PartialEq for GetSubscriberCount
Sourceimpl Serialize for GetSubscriberCount
impl Serialize for GetSubscriberCount
Sourceimpl Unbind for GetSubscriberCount
impl Unbind for GetSubscriberCount
impl<A> Accepts<GetSubscriberCount> for ActorMeshController<A>where
A: Referable,
impl<A> RemoteHandles<GetSubscriberCount> for ActorMeshController<A>where
A: Referable,
impl StructuralPartialEq for GetSubscriberCount